@@ -274,6 +274,10 @@ class netsnmpAgent(object):
 						self._cvar.value = val
 						self._data_size  = len(val)
 
+				if props["asntype"] in [ASN_COUNTER, ASN_COUNTER64]:
+					def increment(self, count=1):
+						self.update(self.value() + count)
+
 			cls.__name__ = property_func.__name__
 
 			# Return an instance of the just-defined class to the agent
@@ -643,7 +647,7 @@ class netsnmpAgent(object):
 				row = self._dataset.contents.table.contents.first_row
 				while bool(row):
 					nextrow = row.contents.next
-					libnsa.netsnmp_table_dataset_remove_and_delete_row(
+					libnsX.netsnmp_table_dataset_remove_and_delete_row(
 						self._dataset,
 						row
 					)
@@ -673,9 +677,11 @@ class netsnmpAgent(object):
 		self._started = True
 		libnsa.init_snmp(self.AgentName)
 
-	def check_and_process(self):
-		""" Blocks and processes incoming SNMP requests. """
-		return libnsa.agent_check_and_process(1)
+	def check_and_process(self, block=True):
+		""" Processes incoming SNMP requests.
+		    If optional "block" argument is True (default), the function
+		    will block until a SNMP packet is received. """
+		return libnsa.agent_check_and_process(int(bool(block)))
 
 	def __del__(self):
 		libnsa.snmp_shutdown(self.AgentName)
